@@ -1,5 +1,5 @@
 consol_affect <-
-function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u,rlevel=0)
+function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u)
 {   
   p<-ncol(X)
   gtmp<-rep(0,p)
@@ -10,9 +10,8 @@ function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u,rlevel=0)
       comp<-comp/matrix(sqrt(diag(t(comp)%*%comp)),nrow=n,ncol=ncol(comp),byrow=T)  #normalization de comp
       cova = t(comp) %*% X/(n-1)
       covaC<-  cova^2
-      for (j in (1:p)) {
-        if (rlevel==0) vec=covaC[,j]
-        if (rlevel!=0) vec=c(covaC[,j],rlevel^2*var(X[,j])/(n-1))
+      for (j in (1:p)) {   
+        vec=covaC[,j] 
         maxj<-which.max(vec)
         gtmp[j] = maxj[1]   
       }
@@ -21,8 +20,7 @@ function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u,rlevel=0)
       cova = t(comp) %*% X/(n-1)
       covaC <- cova^2
       for (j in (1:p)) {
-        if (rlevel==0) vec=covaC[,j]
-        if (rlevel!=0) vec=c(covaC[,j],rlevel^2*var(X[,j])/(n-1))
+        vec=covaC[,j]
         maxj<-which.max(vec)
         gtmp[j] = maxj[1]   
       }
@@ -31,8 +29,7 @@ function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u,rlevel=0)
       cova = t(comp) %*% X/(n-1)
       covaC <- cova^2
       for (j in (1:p)) {
-        if (rlevel==0) vec=covaC[,j]
-        if (rlevel!=0) vec=c(covaC[,j],rlevel^2*var(X[,j])/(n-1))
+        vec=covaC[,j]
         maxj<-which.max(vec)
         gtmp[j] = maxj[1]   
       }
@@ -45,8 +42,7 @@ function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u,rlevel=0)
       cova = t(comp) %*% X/(n-1)
       covaC<-  cova
       for (j in (1:p)) {
-        if (rlevel==0) vec=cova[,j]
-        if (rlevel!=0) vec=c(cova[,j],rlevel*sqrt(var(X[,j])/(n-1)))
+        vec=cova[,j]
         maxj<-which.max(vec)
         gtmp[j] = maxj[1]   
       }
@@ -55,8 +51,7 @@ function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u,rlevel=0)
       cova = t(comp) %*% X/(n-1)
       covaC <- cova
       for (j in (1:p)) {
-        if (rlevel==0) vec=cova[,j]
-        if (rlevel!=0) vec=c(cova[,j],rlevel*sqrt(var(X[,j])/(n-1)))
+        vec=cova[,j]
         maxj<-which.max(vec)
         gtmp[j] = maxj[1]   
       }
@@ -65,8 +60,7 @@ function(method,X,Xr,Xu,EXTr,EXTu,comp,a,u,rlevel=0)
       for (j in 1:p) {
         Pj<- as.matrix(X[,j])%*%Xu[j,]
         critind=diag(t(u)%*%t(Pj)%*%comp)  
-        if (rlevel==0) vec=critind
-        if (rlevel!=0) vec=c(critind,rlevel*sqrt(var(X[,j])/(n-1)))
+        vec=critind
         maxj<-which.max(vec)
         gtmp[j] = maxj[1]                    
       }
